@@ -146,15 +146,12 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                     error_message = 'Backend server didn\'t respond with a token'
                     raise Exception
 
-            request.META[proxy_server.CSRF_COOKIE_USED] = True
+            #request.META[proxy_server.CSRF_COOKIE_USED] = True
 
             resp = HttpResponse(response_data, status=response.status, content_type='application/json', reason=response.reason)
             for header, value in response.getheaders():
                 resp[header] = value
 
-            '''if not resp.has_header(proxy_server.CSRF_TOKEN):
-                resp[proxy_server.CSRF_TOKEN] = get_token(request)'''
-
             return resp
         else:
             if proxy_server.ERROR in response_json:
